@@ -175,18 +175,19 @@ const QString Mixer::dbusPath()
 	// So once the first MixDevice is created, this must return the correct value
 	if (_id.isEmpty())
 	{
-		if (! _mixerBackend->_cardRegistered)
+		bool wasRegistered = _mixerBackend->_cardRegistered;
+		// Bug 308014: Actually this a shortcut (you could also call it a hack). It would likely better if registerCard()
+		//             would create the Id, but it requires cooperation from ALL backends. Also Mixer->getId() would need to
+		//             proxy that to the backend.
+		// So for now we lazily create the MixerId here, while creating the first MixDevice for that card.
+		recreateId();
+		if (! wasRegistered)
 		{
 			// Bug 308014: By checking _cardRegistered, we can be sure that everything is fine, including the fact that
 			// the cardId (aka "card instance") is set. If _cardRegistered would be false, we will create potentially
 			// wrong/duplicated DBUS Paths here.
 			qCWarning(KMIX_LOG) << "Mixer id was empty when creating DBUS path. Emergency code created the id=" <<_id;
 		}
-		// Bug 308014: Actually this a shortcut (you could also call it a hack). It would likely better if registerCard()
-		//             would create the Id, but it requires cooperation from ALL backends. Also Mixer->getId() would need to
-		//             proxy that to the backend.
-		// So for now we lazily create the MixerId here, while creating the first MixDevice for that card.
-		recreateId();
 	}
 
 	// mixerName may contain arbitrary characters, so replace all that are not allowed to be be part of a DBUS path
@@ -197,7 +198,7 @@ const QString Mixer::dbusPath()
     return QString("/Mixers/" + cardPath);
 }
 
-void Mixer::volumeSave( KConfig *config )
+void Mixer::volumeSave(KConfig *config) const
 {
     //    qCDebug(KMIX_LOG) << "Mixer::volumeSave()";
     _mixerBackend->readSetFromHW();
@@ -210,7 +211,7 @@ void Mixer::volumeSave( KConfig *config )
     config->sync();
 }
 
-void Mixer::volumeLoad( KConfig *config )
+void Mixer::volumeLoad(KConfig *config)
 {
    QString grp("Mixer");
    grp.append(id());
@@ -325,7 +326,7 @@ void Mixer::readSetFromHWforceUpdate() const {
 }
 
   /// Returns translated WhatsThis messages for a control.Translates from 
-QString Mixer::translateKernelToWhatsthis(const QString &kernelName)
+QString Mixer::translateKernelToWhatsthis(const QString &kernelName) const
 {
    return _mixerBackend->translateKernelToWhatsthis(kernelName);
 }
@@ -591,7 +592,7 @@ shared_ptr<MixDevice> Mixer::find(const QString& mixdeviceID) const
 }
 
 
-shared_ptr<MixDevice> Mixer::getMixdeviceById( const QString& mixdeviceID )
+shared_ptr<MixDevice> Mixer::getMixdeviceById( const QString& mixdeviceID ) const
 {
 	qCDebug(KMIX_LOG) << "id=" << mixdeviceID << "md=" << _mixerBackend->m_mixDevices.get(mixdeviceID).get()->id();
 	return _mixerBackend->m_mixDevices.get(mixdeviceID);
@@ -700,7 +701,7 @@ void Mixer::setDynamic ( bool dynamic )
     m_dynamic = dynamic;
 }
 
-bool Mixer::isDynamic()
+bool Mixer::isDynamic() const
 {
     return m_dynamic;
 }
@@ -719,3 +720,11 @@ QString Mixer::currentStreamDevice(const QString &id) const
 {
     return (_mixerBackend->currentStreamDevice(id));
 }
+
+
+QString Mixer::iconName() const
+{
+    const shared_ptr<MixDevice> master = getLocalMasterMD();
+    if (master!=nullptr) return (master->iconName());
+    return ("media-playback-start");			// fallback default icon
+}
